from typing import Any, List, Optional


class ClientCorporation:
    id: int
    address: str
    annualRevenue: float
    billingAddress: str
    billingContact: Optional[str]
    billingFrequency: Optional[str]
    billingPhone: Optional[str]
    businessSectorList: str
    childClientCorporations: List[int]
    clientCorporationCertifications: List[int]
    clientContacts: List[int]
    companyDescription: str
    companyURL: Optional[str]
    competitors: str
    culture: str
    customDate1: Optional[int]
    customDate2: Optional[int]
    customDate3: Optional[int]
    customFloat1: Optional[float]
    customFloat2: Optional[float]
    customFloat3: Optional[float]
    customObject1s: List[Any]
    customObject2s: List[Any]
    customObject3s: List[Any]
    customObject4s: List[Any]
    customObject5s: List[Any]
    customObject6s: List[Any]
    customObject7s: List[Any]
    customObject8s: List[Any]
    customObject9s: List[Any]
    customObject10s: List[Any]
    customText1: Optional[str]
    customText2: Optional[str]
    customText3: Optional[str]
    customText4: Optional[str]
    customText5: Optional[str]
    customText6: Optional[str]
    customText7: Optional[str]
    customText8: Optional[str]
    customText9: Optional[str]
    customText10: Optional[str]
    customText11: Optional[str]
    customText12: Optional[str]
    customText13: Optional[str]
    customText14: Optional[str]
    customText15: Optional[str]
    customText16: Optional[str]
    customText17: Optional[str]
    customText18: Optional[str]
    customText19: Optional[str]
    customText20: Optional[str]
    customTextBlock1: Optional[str]
    customTextBlock2: Optional[str]
    customTextBlock3: Optional[str]
    customTextBlock4: Optional[str]
    customTextBlock5: Optional[str]
    dateAdded: int
    dateFounded: Optional[int]
    dateLastModified: int
    department: Optional[int]
    externalID: Optional[str]
    exemptionStatus: Optional[str]
    feeArrangement: float
    funding: str
    industryList: str
    invoiceFormat: Optional[str]
    invoiceGroups: List[int]
    invoices: List[int]
    leads: List[int]
    name: str
    notes: str
    numEmployees: int
    numOffices: int
    owners: List[int]
    ownerShip: Optional[str]
    parentClientCorporation: Optional[int]
    phone: Optional[str]
    rateCards: List[int]
    revenue: str
    requirements: List[int]
    status: str
    taxRate: Optional[float]
    tickerSymbol: Optional[str]
    workWeekStart: Optional[int]
